@@ -69,6 +69,8 @@ SUPPORTEDARCHS = [
     'aarch64',
     'mips',
     'mipsel',
+    'riscv32',
+    'riscv64',
     ]
 
 USERID = pwd.getpwuid(os.getuid())[0]
@@ -247,6 +249,8 @@ def prepare_depanneur_simple_opts(args):
         cmd_opts += ['--export-only']
     if args.with_submodules:
         cmd_opts += ['--with-submodules']
+    if args.nocumulate:
+        cmd_opts += ['--nocumulate']
 
     return cmd_opts
 
@@ -304,6 +308,9 @@ def prepare_depanneur_opts(args):
     if args.profiling:
         cmd_opts += ['--profiling=%s' % args.profiling]
 
+    if args.release:
+        cmd_opts += ['--release=%s' % args.release]
+
     cmd_opts += ['--threads=%s' % args.threads]
     if args.kvm:
         loopdev = len([name for name in os.listdir('/dev') if bool(re.search("loop[0-9]",name))])
@@ -617,6 +624,9 @@ def prepare_depanneur_cmd(args, buildarch, profile, workdir):
     if args.ccache:
         cmd += ['--ccache']
 
+    if args.pkg_ccache:
+        cmd += ['--pkg-ccache=%s' % args.pkg_ccache]
+
     if args.extra_packs:
         cmd += ['--extra-packs=%s' % args.extra_packs]
 
